==> bibledit-1.4.tar.gz: bibledit-1.4/src/dialogunicode.h <==
/*
** Copyright (C) 2003-2005 The Free Software Foundation.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/

#ifndef INCLUDED_DIALOGUNICODE_H
#define INCLUDED_DIALOGUNICODE_H


#include <gtk/gtk.h>


void unicode_convert (const ustring& path, const ustring& encoding);


class UnicodeDialog
{
public:
  UnicodeDialog (const ustring & filetoconvert);
  virtual ~ UnicodeDialog ();
  virtual int run ();
  ustring encoding;
protected:
  GtkWidget *unicodedialog;
  GtkWidget *dialog_vbox1;
  GtkWidget *label1;
  GtkWidget *vbox1;
  GtkWidget *combobox1;
  GtkWidget *scrolledwindow1;
  GtkWidget *textview1;
  GtkWidget *dialog_action_area1;
  GtkWidget *okbutton1;
private:
  ustring filename;
  static void unicodedialog_on_combo_entry1_changed (GtkEditable * editable, gpointer user_data);
  virtual void on_combo_changed ();
  static bool on_combobox1_key_press_event (GtkWidget *widget, GdkEventKey *event, gpointer user_data);
  bool on_combobox1_key_press (GdkEventKey *event);
};


#endif

==> bibledit-1.5.tar.gz: bibledit-1.5/src/dialogunicode.h <==
/*
** Copyright (C) 2003-2005 The Free Software Foundation.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/

#ifndef INCLUDED_DIALOGUNICODE_H
#define INCLUDED_DIALOGUNICODE_H


#include <gtk/gtk.h>


void unicode_convert (const ustring& path, const ustring& encoding);


class UnicodeDialog
{
public:
  UnicodeDialog (const ustring & filetoconvert);
  virtual ~ UnicodeDialog ();
  virtual int run ();
  ustring encoding;
protected:
  GtkWidget *unicodedialog;
  GtkWidget *dialog_vbox1;
  GtkWidget *label1;
  GtkWidget *vbox1;
  GtkWidget *button1;
  GtkWidget *scrolledwindow1;
  GtkWidget *textview1;
  GtkWidget *dialog_action_area1;
  GtkWidget *okbutton1;
private:
  ustring filename;
  vector <ustring> encodings;
  virtual void set_gui ();
  static void on_button1_clicked (GtkButton *button, gpointer user_data);
  virtual void on_button1 ();
};


#endif
